@@ -174,6 +174,7 @@ print
 print "Testing bulk load speed for %d rows..." % (ROWS,)
 # Speed difference in inserts using bulkload vs inserts
 import itertools
+
 # for loop using prepared statement
 db.execute("delete from demo")
 t1 = time.time()
@@ -184,7 +185,21 @@ for (c1,c2) in itertools.izip(
     ):
     cu.execute(c1, c2)
 tinsert = time.time() - t1
-print "INSERT   %d rows: %.2f sec (%s)" % (ROWS, tinsert, "baseline")
+print "INSERT PREPARED %d rows: %.2f sec (%s)" % (ROWS, tinsert, "baseline")
+
+# multival insert
+db.execute("delete from demo")
+cu = db.cursor()
+t1 = time.time()
+q = "INSERT INTO demo (name, blobval) VALUES "
+qvals = ",".join( "('%s','%s')" % (a,b) for a,b in
+                  itertools.izip( ("name%dvalue" % x for x in xrange(ROWS)),
+                                  ("blobval%dvalue" % x for x in xrange(ROWS)) )
+                  )
+cu.execute(q+qvals)
+tmultival = time.time() - t1
+print "INSERT MULTIVAL %d rows: %.2f sec (%s)" % (ROWS, tmultival, pct(tinsert, tmultival))
+
 # bulkload
 db.execute("delete from demo")
 t1 = time.time()
@@ -193,7 +208,7 @@ db.bulkload("demo", itertools.izip(
     ("blobval%dvalue" % x for x in xrange(ROWS))
     ), ("name", "blobval"))
 tbulk = time.time() - t1
-print "BULKLOAD %d rows: %.2f sec (%s)" % (ROWS, tbulk, pct(tinsert, tbulk))
+print "INSERT BULKLOAD %d rows: %.2f sec (%s)" % (ROWS, tbulk, pct(tinsert, tbulk))
 
 #
 # DEMO DONE
