@@ -340,7 +340,6 @@ pg_inserttable(pgobject *self, PyObject *args)
     Oid		*coltypes = NULL;
     PyObject	*iterRows = NULL;
 
-
     /* checks validity */
     if (!check_pg_obj(self))
 	return NULL;
@@ -383,7 +382,7 @@ pg_inserttable(pgobject *self, PyObject *args)
     result = PQexec(self->cnx, buffer);
     Py_END_ALLOW_THREADS ;
     _xfree(buffer);
-
+    
     if (!result) {
 	PyErr_SetString(PyExc_ValueError, PQerrorMessage(self->cnx));
 	_xfree(coltypes);
@@ -480,6 +479,21 @@ pg_inserttable(pgobject *self, PyObject *args)
 	PyErr_SetString(ProgrammingError, PQerrorMessage(self->cnx));
 	goto bad_exit;
     }
+    /* need to check for the final result of the copy command */
+    while ( (result = PQgetResult(self->cnx) ) ) {
+        switch (PQresultStatus(result)) {
+            case PGRES_BAD_RESPONSE:
+            case PGRES_FATAL_ERROR:
+            case PGRES_NONFATAL_ERROR:
+                PyErr_SetString(ProgrammingError, PQresultErrorMessage(result));
+                PQclear(result);
+                goto bad_exit;
+            default:
+                PQclear(result);
+                continue;
+        }
+    }
+
     /* no error : returns nothing */
     Py_DECREF(iterRows);
     free(coltypes);
