@@ -54,7 +54,7 @@ static PyObject *Error, *Warning, *InterfaceError,
 	*DatabaseError, *InternalError, *OperationalError, *ProgrammingError,
 	*IntegrityError, *DataError, *NotSupportedError;
 
-static const char *PyPgVersion = "0.9.6";
+static const char *PyPgVersion = "0.9.7";
 static char pg__doc__[] = "Simple Python interface to PostgreSQL DB";
 
 /* default values */
@@ -1004,8 +1004,8 @@ _pg_fetch_cell(PGresult *result, int row, int col)
 		void *tmpstr = NULL;
 		Py_ssize_t tmplen = 0;
 		int retcode = 0;
-		fprintf(stderr, "WARNING: Unknown datatype %d processed as string. "
-			"Check pg_type.h to decode this OID\n", oidtype);
+		fprintf(stderr, "WARNING: UNKNOWN DATATYPE %ld processed as string. "
+			"Check pg_type.h to decode this OID\n", (long)oidtype);
 		if (!(ret = PyBuffer_New(cellsize)) || ret == PyExc_ValueError) {
 		    PyErr_SetString(PyExc_MemoryError, "could not allocate buffer object for row data");
 		    return NULL;
